==> ktp-text-ui-0.6.80.tar.bz2: ktp-text-ui-0.6.80/filters/urlexpansion/ktptextui_message_filter_urlexpansion.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Name=Short URLs
Name[ca]=URL breus
Name[cs]=Krátké URL
Name[da]=Korte URL'er
Name[de]=Kurz-URLs
Name[el]=Συντομευμένα URL
Name[es]=URL abreviadas
Name[fi]=Lyhyet verkko-osoitteet
Name[fr]=URL réduites
Name[gl]=Enderezos URL curtos
Name[hu]=Rövid URL-ek
Name[ia]=Monstra URLs
Name[it]=URL brevi
Name[nl]=Korte URL's
Name[pa]=ਛੋਟੇ URL
Name[pt]=URL's Curtos
Name[pt_BR]=URLs curtas
Name[ro]=URL-uri scurte
Name[ru]=Короткие адреса
Name[sk]=Krátke URL
Name[sl]=Kratki naslovi URL
Name[sr]=Кратки УРЛ‑ови
Name[sr@ijekavian]=Кратки УРЛ‑ови
Name[sr@ijekavianlatin]=Kratki URL‑ovi
Name[sr@latin]=Kratki URL‑ovi
Name[sv]=Korta webbadresser
Name[tr]=Kısa adresler
Name[uk]=Короткі адреси
Name[x-test]=xxShort URLsxx
Name[zh_TW]=短網址
Comment=Shows the actual URL to which a shortened URL is redirecting to
Comment[ca]=Mostra l'URL real al que es redirigeix un URL breu
Comment[cs]=Zobrazí skutečné URL, na které je přesměrováno zkrácené URL
Comment[da]=Viser den faktiske URL som en afkortet URL videresender til
Comment[de]=Zeigt die tatsächliche Adresse (URL), auf die eine gekürzte URL umgeleitet wird
Comment[el]=Εμφανίζει το πραγματικό URL στο οποίο ανακατευθύνεται το συντομευμένο
Comment[es]=Muestra la URL real a la que redirecciona una URL abreviada
Comment[fi]=Näyttää, mihin osoitteeseen lyhennetty verkko-osoite ohjaa
Comment[fr]=Affiche l'URL courante vers laquelle pointe une URL réduite
Comment[gl]=Mostra o URL real ao que dirixe un URL acurtado.
Comment[hu]=Megjeleníti azt az aktuális URL-t, amelyre a rövidített URL átirányít
Comment[ia]=Il monstra le URL actual ubi on redirige un URL abbreviate
Comment[it]=Mostra l'URL vero a cui si viene rediretti da un URL abbreviato
Comment[nl]=Toont de actuele URL waarnaar de korte URL verwijst
Comment[pt]=Mostra o URL real para onde aponta um URL curto
Comment[pt_BR]=Mostra a URL real para onde direciona uma URL curta
Comment[ro]=Arată URL-ul real spre care redirecționează un URL scurtat
Comment[ru]=Показывать полные адреса URL, на которые перенаправляют сокращённые
Comment[sk]=Zobrazí aktuálne URL, na ktoré je presmerované skrátené URL
Comment[sl]=Prikaže dejanski URL na katerega kaže skrajšan URL
Comment[sr]=Приказује стварни УРЛ на који скраћени преусмерава
Comment[sr@ijekavian]=Приказује стварни УРЛ на који скраћени преусмерава
Comment[sr@ijekavianlatin]=Prikazuje stvarni URL na koji skraćeni preusmerava
Comment[sr@latin]=Prikazuje stvarni URL na koji skraćeni preusmerava
Comment[sv]=Visar den verkliga webbadressen som en avkortad webbadress leder till
Comment[tr]=Kısaltılmış URL'nin yönlendireceği asıl URL'yi gösterir
Comment[uk]=Показує справжню адресу, до якої переспрямовуватиме вас скорочена адреса
Comment[x-test]=xxShows the actual URL to which a shortened URL is redirecting toxx
Comment[zh_TW]=顯示短網址將導向的實際網址
Type=Service
ServiceTypes=KTpTextUi/MessageFilter
X-KDE-Library=ktptextui_message_filter_urlexpansion
X-KDE-PluginInfo-Author=Anant Kamath
X-KDE-PluginInfo-Email=kamathanant@gmail.org
X-KDE-PluginInfo-Name=urlexpansion
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@

==> ktp-text-ui-0.7.0.tar.bz2: ktp-text-ui-0.7.0/filters/urlexpansion/ktptextui_message_filter_urlexpansion.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Name=Short URLs
Name[bs]=Kratke URL adrese
Name[ca]=URL breus
Name[ca@valencia]=URL breus
Name[cs]=Krátké URL
Name[da]=Korte URL'er
Name[de]=Kurz-URLs
Name[es]=URL abreviadas
Name[fi]=Lyhyet verkko-osoitteet
Name[fr]=URL réduites
Name[hu]=Rövid URL-ek
Name[ia]=URLs breve
Name[it]=URL brevi
Name[kk]=Қысқа URL-дер
Name[nl]=Korte URL's
Name[pt]=URL's Curtos
Name[pt_BR]=URLs curtas
Name[ru]=Короткие адреса
Name[sk]=Krátke URL
Name[sl]=Kratki naslovi URL
Name[sv]=Korta webbadresser
Name[uk]=Короткі адреси
Name[x-test]=xxShort URLsxx
Name[zh_CN]=短 URL
Name[zh_TW]=短網址
Comment=Shows the actual URL to which a shortened URL is redirecting to
Comment[bs]=Prikazuje stvarni URL na koji je skraćeni preusmjeren
Comment[ca]=Mostra l'URL real al que es redirigeix un URL breu
Comment[ca@valencia]=Mostra l'URL real al que es redirigeix un URL breu
Comment[cs]=Zobrazí skutečné URL, na které je přesměrováno zkrácené URL
Comment[da]=Viser den faktiske URL som en afkortet URL videresender til
Comment[de]=Zeigt die tatsächliche Adresse (URL), auf die eine gekürzte URL umgeleitet wird
Comment[es]=Muestra la URL real a la que redirecciona una URL abreviada
Comment[fi]=Näyttää, mihin osoitteeseen lyhennetty verkko-osoite ohjaa
Comment[fr]=Affiche l'URL courante vers laquelle pointe une URL réduite
Comment[hu]=Megjeleníti azt az aktuális URL-t, amelyre a rövidített URL átirányít
Comment[ia]=Monstra le URL actual al qual on reinvia URL abbreviate
Comment[it]=Mostra l'URL vero a cui si viene rediretti da un URL abbreviato
Comment[kk]=Қысқа URL бағыттайтын шын URL-адресін көрсету
Comment[nl]=Toont de actuele URL waarnaar de korte URL verwijst
Comment[pt]=Mostra o URL real para onde aponta um URL curto
Comment[pt_BR]=Mostra a URL real para onde direciona uma URL curta
Comment[ru]=Показывать полные адреса URL, на которые перенаправляют сокращённые
Comment[sk]=Zobrazí aktuálne URL, na ktoré je presmerované skrátené URL
Comment[sl]=Prikaže dejanski URL na katerega kaže skrajšan URL
Comment[sv]=Visar den verkliga webbadressen som en avkortad webbadress leder till
Comment[uk]=Показує справжню адресу, до якої переспрямовуватиме вас скорочена адреса
Comment[x-test]=xxShows the actual URL to which a shortened URL is redirecting toxx
Comment[zh_CN]=显示短 URL 的实际 URL
Comment[zh_TW]=顯示短網址所轉換的實際網址
Type=Service
ServiceTypes=KTpTextUi/MessageFilter
X-KDE-Library=ktptextui_message_filter_urlexpansion
X-KDE-PluginInfo-Author=Anant Kamath
X-KDE-PluginInfo-Email=kamathanant@gmail.org
X-KDE-PluginInfo-Name=urlexpansion
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@
